@@ -9,7 +9,7 @@ import random
 import datetime,time
 import logging
 import re
-import urllib.parse 
+import urllib.parse
 
 mode ='local'
 
@@ -579,11 +579,12 @@ def derivative_history_virgin(symbol,start_date,end_date,instrumentType,expiry_d
     instrumentType = instrumentType.lower()
 
     if(instrumentType=="options"):
-        if("NIFTY" in symbol): instrumentType="FUTSTK"
         instrumentType="OPTSTK"
-    if(instrumentType=="futures"):
         if("NIFTY" in symbol): instrumentType="OPTIDX"
-        instrumentType="FUTIDX"
+        
+    if(instrumentType=="futures"):
+        instrumentType="FUTSTK"
+        if("NIFTY" in symbol): instrumentType="FUTIDX"
 
     if(((instrumentType=="OPTIDX")or (instrumentType=="OPTSTK")) and (expiry_date!="")):
         strikePrice = "%.2f" % strikePrice
